<?php

namespace Drupal\monolog;

use Drupal\Core\Logger\RfcLogLevel;
use Monolog\Level;

/**
 * Methods to convert between Monolog and Drupal log levels.
 */
trait LevelMapperTrait {

  /**
   * Convert a Drupal log level to a Monolog log level.
   *
   * @param int $level
   *   The Drupal log level.
   *
   * @return \Monolog\Level
   *   The Monolog log level.
   */
  public function fromRfc5424ToMonolog(int $level): Level {
    return match ($level) {
      RfcLogLevel::EMERGENCY => Level::Emergency,
      RfcLogLevel::ALERT => Level::Alert,
      RfcLogLevel::CRITICAL => Level::Critical,
      RfcLogLevel::ERROR => Level::Error,
      RfcLogLevel::WARNING => Level::Warning,
      RfcLogLevel::NOTICE => Level::Notice,
      RfcLogLevel::INFO => Level::Info,
      default => Level::Debug,
    };
  }

  /**
   * Convert a Monolog log level to a Drupal log level.
   *
   * @param \Monolog\Level $level
   *   The Monolog log level.
   *
   * @return int
   *   The Drupal log level.
   */
  public function fromMonologToRfc5424(Level $level): int {
    return match ($level) {
      Level::Emergency => RfcLogLevel::EMERGENCY,
      Level::Alert => RfcLogLevel::ALERT,
      Level::Critical => RfcLogLevel::CRITICAL,
      Level::Error => RfcLogLevel::ERROR,
      Level::Warning => RfcLogLevel::WARNING,
      Level::Notice => RfcLogLevel::NOTICE,
      Level::Info => RfcLogLevel::INFO,
      default => RfcLogLevel::DEBUG,
    };
  }

}
