<?php

declare(strict_types=1);

namespace Drupal\monolog\Logger\Handler;

use Drupal\monolog\LevelMapperTrait;
use Monolog\Handler\AbstractProcessingHandler;
use Monolog\Level;
use Monolog\LevelName;
use Monolog\LogRecord;
use Psr\Log\LoggerInterface;

/**
 * Forwards logs to a Drupal logger.
 */
class DrupalHandler extends AbstractProcessingHandler {

  use LevelMapperTrait;

  /**
   * The wrapped Drupal logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected LoggerInterface $logger;

  /**
   * Constructs a Default object.
   *
   * @param \Psr\Log\LoggerInterface $wrapped
   *   The wrapped Drupal logger.
   * @param int|string|\Monolog\Level|\Monolog\LevelName|\Psr\Log\LogLevel $level
   *   The minimum logging level at which this handler will be triggered.
   * @param bool $bubble
   *   Whether the messages that are handled can bubble up the stack or not.
   */
  public function __construct(
    LoggerInterface $wrapped,
    int|string|Level|LevelName $level = Level::Debug,
    bool $bubble = TRUE
  ) {
    parent::__construct($level, $bubble);

    $this->logger = $wrapped;
  }

  /**
   * {@inheritdoc}
   */
  public function write(LogRecord $record): void {
    // Set up context with the data Drupal loggers expect.
    // @see Drupal\Core\Logger\LoggerChannel::log()
    $extra = $record->extra;
    $context = $record->context + [
      'uid' => $extra['uid'] ?? 0,
      'channel' => $record->channel,
      'link' => '',
      'request_uri' => $extra['request_uri'] ?? '',
      'referer' => $extra['referer'] ?? '',
      'ip' => $extra['ip'] ?? 0,
      'timestamp' => $record->datetime->format('U'),
    ];

    $this->logger->log(
      $this->fromMonologToRfc5424($record->level),
      $record->message,
      $context
    );
  }

}
