<?php

declare(strict_types=1);

namespace Drupal\monolog\Logger;

use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Logger\RfcLogLevel;
use Drupal\Core\Session\AccountInterface;
use Drupal\monolog\LevelMapperTrait;
use Monolog\Level;
use Monolog\Logger as BaseLogger;
use Psr\Log\LoggerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Logger class for the Drupal Monolog module.
 *
 * Allows the channel to be modified after the class is instantiated. This is
 * normally not a good idea, but it is necessary to reconcile the differences in
 * the Monolog library and how the watchdog type relates to the logging
 * facility.
 */
class Logger extends BaseLogger implements LoggerChannelInterface {

  use LevelMapperTrait;

  /**
   * {@inheritdoc}
   */
  public function addRecord(int|Level $level, string $message, array $context = []): bool {
    if (in_array($level, array_keys(RfcLogLevel::getLevels()))) {
      $level = $this->fromRfc5424ToMonolog($level);
    }

    return parent::addRecord($level, $message, $context);
  }

  /**
   * {@inheritdoc}
   */
  public function log($level, string|\Stringable $message, array $context = []): void {
    if (in_array($level, array_keys(RfcLogLevel::getLevels()))) {
      $level = $this->fromRfc5424ToMonolog($level);
    }

    parent::log($level, $message, $context);
  }


  /**
   * {@inheritdoc}
   */
  public function setRequestStack(RequestStack $requestStack = NULL) {
    // Do nothing, use a handler for this.
  }

  /**
   * {@inheritdoc}
   */
  public function setCurrentUser(AccountInterface $current_user = NULL) {
    // Do nothing, use a handler for this.
  }

  /**
   * {@inheritdoc}
   */
  public function setLoggers(array $loggers) {
    // Do nothing.
  }

  /**
   * {@inheritdoc}
   */
  public function addLogger(LoggerInterface $logger, $priority = 0) {
    // Do nothing.
  }

}
